empiricals - module with heliospheric empirical modules — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »

# empiricals - module with heliospheric empirical modules

Module with some useful empirical models (plasmapause, magnetopause, Lmax)

Authors: Steve Morley, Josef Koller Institution: Los Alamos National Laboratory Contact: smorley@lanl.gov

Copyright 2010 Los Alamos National Security, LLC.

`getLmax`(ticks[, model]) | calculate a simple empirical model for Lmax - last closed drift-shell
`getPlasmaPause`(ticks[, model, LT, omnivals]) | Plasmapause location model(s)
`getMPstandoff`(ticks) | Calculates the Shue et al.
`getDststar`(ticks[, model]) | Calculate the pressure-corrected Dst index, Dst*
`getVampolaOrder`(L) | Empirical lookup of power for sin^n pitch angle model from Vampola (1996)
`vampolaPA`(omniflux, **kwargs) | Pitch angle model of sin^n form

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »